library(testthat)
library(latrend)

test_check('latrend')
